@@ -213,10 +213,14 @@ def add_properties(board, motors=None, servos=None, adcs=None, default_adc_divis
 
     # Set up configuration dict, we only add top level keys if the corresponding facility is requested
     config = {}
-    if motors: board._config[MOTORS] = {}
-    if servos: board._config[SERVOS] = {}
-    if adcs: board._config[ADCS] = {}
-    if leds: board._config[LEDS] = {}
+    if motors:
+        config[MOTORS] = {}
+    if servos:
+        config[SERVOS] = {}
+    if adcs:
+        config[ADCS] = {}
+    if leds:
+        config[LEDS] = {}
 
     # Inject mXX, motorXX, mXX_invert, and motorXX_invert properties
     for motor in motors:
@@ -250,4 +254,3 @@ def add_properties(board, motors=None, servos=None, adcs=None, default_adc_divis
     # Set the supplied object's class to the newly created subclass
     board._config = config
     board.__class__ = Board
-
