@@ -46,7 +46,8 @@ def build_curses_gui(board, motor_keys=DEFAULT_MOTOR_KEYS, servo_keys=DEFAULT_SE
 
     def curses_main(screen):
         try:
-            display = DisplayState(screen=screen, board=board)
+            display = DisplayState(screen=screen, board=board, motor_keys=motor_keys, servo_keys=servo_keys,
+                                   adc_keys=adc_keys)
             curses.cbreak()
             curses.halfdelay(1)
             while True:
